@@ -309,21 +309,7 @@ class AirHumidifier(Device):
         if self.model in [MODEL_HUMIDIFIER_CA1, MODEL_HUMIDIFIER_CB1]:
             _props_per_request = 1
 
-        _props = properties.copy()
-        values = []
-        while _props:
-            values.extend(self.send("get_prop", _props[:_props_per_request]))
-            _props[:] = _props[_props_per_request:]
-
-        properties_count = len(properties)
-        values_count = len(values)
-        if properties_count != values_count:
-            _LOGGER.error(
-                "Count (%s) of requested properties does not match the "
-                "count (%s) of received values.",
-                properties_count,
-                values_count,
-            )
+        values = self.get_properties(properties, max_properties=_props_per_request)
 
         return AirHumidifierStatus(
             defaultdict(lambda: None, zip(properties, values)), self.device_info
